
from biftest.request import Request
# 패키지를 만들때는 앞에 패키지명을 붙여주는게 좋음

class Dashboards(Request):

    def __init__(self, url, token):
        super().__init__(url, token)

    def get_list(self, params):
        endpoint = self.url + 'dashboards'
        return self._get_request(endpoint, params)
        
    def create(self, data):
        endpoint = self.url + 'dashboards'
        return self._post_request(endpoint, data)
    
    def clone(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/clone'
        return self._post_request(endpoint, data)
    
    def put(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/put'
        return self._post_request(endpoint, data)
        
    def delete(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/delete'
        return self._post_request(endpoint, data)
        
    def get_permission(self, inputId, params):
        endpoint = self.url + 'dashboards/' + inputId + '/permission'
        return self._get_request(endpoint, params)
        
    def users_regist(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/users'
        return self._post_request(endpoint, data)
        
    def users_put(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/users/put'
        return self._post_request(endpoint, data)
        
    def users_delete(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/users/delete'
        return self._post_request(endpoint, data)
        
    def groups_regist(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/groups'
        return self._post_request(endpoint, data)
        
    def groups_put(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/groups/put'
        return self._post_request(endpoint, data)
        
    def groups_delete(self, inputId, data):
        endpoint = self.url + 'dashboards/' + inputId + '/permission/groups/delete'
        return self._post_request(endpoint, data)


import pandas as pd
import matplotlib.pyplot as plt
import matplotlib as mpl
import seaborn as sns
import json


def joinplot(jsonData, xStr, yStr):
    insertData = json.dumps(jsonData)
    df = pd.read_json(insertData, encoding='utf-8')
    
    plt.rcParams['font.family'] = 'Malgun Gothic'
    mpl.rcParams['axes.unicode_minus']=False

    sns.jointplot(x=xStr, y=yStr, data=df, kind='reg')

    plt.show()


def helloBix5():
    print('helloBix5')

# 예시로 xStr, yStr를 지정
#xStr = '유입량'
#yStr = '방류량'

# 예시로 JSON 파일 경로를 지정
#file_path = 'sewerData.json'

#with open(file_path, 'r', encoding='utf-8') as file:
#    json_data = json.load(file)

# joinplot 함수 호출
#joinplot(json_data, xStr, yStr)




import requests
import json

class Request:
    def __init__(self, url, token):
        self.url = url
        self.token = token

    def _get_request(self, endpoint, params=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': 'Bearer ' + self.token
        }
        try:
            response = requests.get(endpoint, headers=headers, params=params, timeout=10) # 10초 타임아웃 설정
            response.raise_for_status()  # HTTPError 예외 발생 시키기
            return response.json()
        except requests.exceptions.HTTPError as e:
            print(f"HTTP 에러 발생: {e.response.status_code} - {e.response.text}")
        except requests.exceptions.ConnectionError:
            print("서버에 연결할 수 없습니다.")
        except requests.exceptions.Timeout:
            print("요청 시간 초과.")
        except requests.exceptions.RequestException as e:
            print(f"요청 실패: {e}")
        except json.decoder.JSONDecodeError:
            print("JSON 디코딩 오류: 응답이 유효한 JSON 형식이 아닙니다."+response.text)
        except Exception as e:
            print(f"알 수 없는 오류 발생: {e}")
        
    def _post_request(self, endpoint, data=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': 'Bearer ' + self.token
        }
        try:
            response = requests.post(endpoint, headers=headers ,json=data, timeout=10) # 10초 타임아웃 설정
            response.raise_for_status()  # HTTPError 예외 발생 시키기
            return response.json()
        except requests.exceptions.HTTPError as e:
            print(f"HTTP 에러 발생: {e.response.status_code} - {e.response.text}")
        except requests.exceptions.ConnectionError:
            print("서버에 연결할 수 없습니다.")
        except requests.exceptions.Timeout:
            print("요청 시간 초과.")
        except requests.exceptions.RequestException as e:
            print(f"요청 실패: {e}")
        except json.decoder.JSONDecodeError:
            print("JSON 디코딩 오류: 응답이 유효한 JSON 형식이 아닙니다."+response.text)
        except Exception as e:
            print(f"알 수 없는 오류 발생: {e}")



from setuptools import setup, find_packages

setup(
name='biftest',
version='0.1.0',
packages=find_packages(),
    install_requires=[
        'pandas>=1.0',
        'matplotlib>=3.1',
        'requests',
        'seaborn>=0.10'
    ]
)



from biftest.request import Request
# 패키지를 만들때는 앞에 패키지명을 붙여주는게 좋음

class Grouops(Request):

    def __init__(self, url, token):
        super().__init__(url, token)

    def get_list(self, params):
        endpoint = self.url + 'groups'
        return self._get_request(endpoint, params)
        
    def regist(self, data):
        endpoint = self.url + 'groups'
        return self._post_request(endpoint, data)
    
    def put(self, inputId, data):
        endpoint = self.url + 'groups/' + inputId + '/put'
        return self._post_request(endpoint, data)
        
    def delete(self, inputId, data):
        endpoint = self.url + 'groups/' + inputId + '/delete'
        return self._post_request(endpoint, data)
    

class Users(Request):

    def __init__(self, url, token):
        super().__init__(url, token)

    def get_info(self,inputId, params):
        endpoint = self.url + 'users/'+inputId
        return self._get_request(endpoint, params)
        
    def create(self, data):
        endpoint = self.url + 'users'
        return self._post_request(endpoint, data)
    
    def put(self, inputId, data):
        endpoint = self.url + 'users/' + inputId + '/put'
        return self._post_request(endpoint, data)

    def update_account(self, inputId, data):
        endpoint = self.url + 'users/' + inputId + '/account'
        return self._post_request(endpoint, data)
    
    def update_status(self, inputId, data):
        endpoint = self.url + 'users/' + inputId + '/enabled'
        return self._post_request(endpoint, data)    
    
    def refresh_token(self, inputId, data):
        endpoint = self.url + 'users/' + inputId + '/refreshToken'
        return self._post_request(endpoint, data)    
            
    def delete(self, inputId, data):
        endpoint = self.url + 'users/' + inputId + '/delete'
        return self._post_request(endpoint, data)